Learn R Programming

dmlalg (version 1.0.2)

residuals.mmdml: Confidence Intervals for coefficient estimates of regsDML fits

Description

A list whose elements correspond to the potentially scaled first nr_res sets of residuals of the S residuals.

Usage

# S3 method for mmdml
residuals(object, scaled = FALSE, ...)

Arguments

object

An object of class mmdml. This object usually results from a function call to mmdml.

scaled

A boolean specifying whether scaled residuals should be returned. It is set to FALSE by default.

...

Further arguments passed to or from other methods.

Value

A list whose elements correspond to the first nr_res sets of residuals of the S residuals.

See Also

mmdml

Examples

Run this code
# NOT RUN {
## See example(mmdml) for examples
# }

Run the code above in your browser using DataLab