powered by
A list whose elements correspond to the potentially scaled first nr_res sets of residuals of the S residuals.
nr_res
S
# S3 method for mmdml residuals(object, scaled = FALSE, ...)
An object of class mmdml. This object usually results from a function call to mmdml.
mmdml
A boolean specifying whether scaled residuals should be returned. It is set to FALSE by default.
Further arguments passed to or from other methods.
A list whose elements correspond to the first nr_res sets of residuals of the S residuals.
# NOT RUN { ## See example(mmdml) for examples # }
Run the code above in your browser using DataLab